@@ -4,6 +4,7 @@ import logging
 import urllib
 import zlib
 import re
+from jinja2 import Template
 
 from flexget.entry import Entry
 from flexget.plugin import register_plugin, internet, PluginError
@@ -12,7 +13,6 @@ from flexget.utils.cached_input import cached
 
 log = logging.getLogger('html')
 
-
 class InputHtml(object):
     """
         Parses urls from html page. Usefull on sites which have direct download
@@ -38,6 +38,14 @@ class InputHtml(object):
         advanced.accept('text', key='title_from')
         regexps = advanced.accept('list', key='links_re')
         regexps.accept('regexp')
+        advanced.accept('boolean', key='increment')
+        increment = advanced.accept('dict', key='increment')
+        increment.accept('integer', key='from')
+        increment.accept('integer', key='to')
+        increment.accept('text', key='name')
+        increment.accept('integer', key='step')
+        increment.accept('boolean', key='stop_when_empty')
+        increment.accept('integer', key='entries_count')
         return root
 
     def build_config(self, config):
@@ -65,25 +73,65 @@ class InputHtml(object):
     def on_task_input(self, task, config):
         config = self.build_config(config)
 
-        log.debug('InputPlugin html requesting url %s' % config['url'])
-
         auth = None
         if config.get('username') and config.get('password'):
             log.debug('Basic auth enabled. User: %s Password: %s' % (config['username'], config['password']))
             auth = (config['username'], config['password'])
-
-        page = task.requests.get(config['url'], auth=auth)
+            
+        increment = config.get('increment')
+        if increment:            
+            entries = None
+            if not isinstance(increment, dict):
+                increment = {}
+            current = increment.get('from', 0)
+            to = increment.get('to')
+            step = increment.get('step', 1)
+            base_url = config['url']
+            entries_count = increment.get('entries_count', 500)
+            stop_when_empty = increment.get('stop_when_empty', True)
+            increment_name = increment.get('name', 'i')
+            
+            template_url = Template(base_url)
+            template_dump = None
+            if 'dump' in config:
+                dump_name = config['dump']
+                if dump_name:
+                    template_dump = Template(dump_name)
+            
+            while to is None or current < to:
+                render_ctx = {increment_name: current}
+                url = template_url.render(**render_ctx)
+                dump_name = None
+                if template_dump:
+                    dump_name = template_dump.render(**render_ctx)
+                new_entries = self._request_url(task, config, url, auth, dump_name)
+                if not entries:
+                    entries = new_entries
+                else:
+                    entries.extend(new_entries)
+                if stop_when_empty and not new_entries:
+                    break
+                if entries_count and len(entries) >= entries_count:
+                    break
+                current = current + step
+            return entries
+        else:
+            return self._request_url(task, config, base_url, auth)
+        
+    def _request_url(self, task, config, url, auth, dump_name = None):
+        log.debug('InputPlugin html requesting url %s' % url)
+        page = task.requests.get(url, auth=auth)
+        log.debug('InputPlugin html response: %s %s' % (page.status_code, page.reason))            
         soup = get_soup(page.text)
 
         # dump received content into a file
-        if 'dump' in config:
-            name = config['dump']
-            log.info('Dumping %s into %s' % (config['url'], name))
+        if dump_name:
+            log.info('Dumping %s into %s' % (url, dump_name))
             data = soup.prettify()
-            with open(name, 'w') as f:
+            with open(dump_name, 'w') as f:
                 f.write(data)
 
-        return self.create_entries(config['url'], soup, config)
+        return self.create_entries(url, soup, config)
 
     def _title_from_link(self, link, log_link):
         title = link.text
